@@ -4,7 +4,7 @@ Manage AWS Batch jobs, queues, and compute environments.
 
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-import os, sys, argparse, base64, collections, io, subprocess, json, time, re, hashlib
+import os, sys, argparse, base64, collections, io, subprocess, json, time, re, hashlib, concurrent.futures, itertools
 
 from botocore.exceptions import ClientError
 
@@ -85,6 +85,7 @@ def create_compute_environment(args):
     else:
         ecs_ami_id = get_ssm_parameter("/aws/service/ecs/optimized-ami/amazon-linux-2/recommended/image_id")
     launch_template = ensure_launch_template(ImageId=ecs_ami_id,
+                                             # TODO: add configurable BDM for Docker image cache space
                                              UserData=base64.b64encode(user_data).decode())
     batch_iam_role = ensure_iam_role(args.service_role, trust=["batch"], policies=["service-role/AWSBatchServiceRole"])
     vpc = ensure_vpc()
@@ -212,6 +213,7 @@ def add_command_args(parser):
                         help="With --cwl, use this file as the CWL job input (default: stdin)")
     parser.add_argument("--environment", nargs="+", metavar="NAME=VALUE",
                         type=lambda x: dict(zip(["name", "value"], x.split("=", 1))), default=[])
+    parser.add_argument("--staging-s3-bucket", help=argparse.SUPPRESS)
 
 def add_job_defn_args(parser):
     parser.add_argument("--ulimits", nargs="*",
@@ -253,18 +255,31 @@ submit_parser.add_argument("--retry-attempts", type=int, default=1,
 submit_parser.add_argument("--dry-run", action="store_true", help="Gather arguments and stop short of submitting job")
 
 def terminate(args):
-    return clients.batch.terminate_job(jobId=args.job_id, reason="Terminated by {}".format(__name__))
+    def terminate_one(job_id):
+        return clients.batch.terminate_job(jobId=job_id, reason=args.reason)
 
-parser = register_parser(terminate, parent=batch_parser, help="Terminate a Batch job")
-parser.add_argument("job_id")
+    with concurrent.futures.ThreadPoolExecutor() as executor:
+        result = list(executor.map(terminate_one, args.job_id))
+        logger.info("Sent termination requests for %d jobs", len(result))
+
+parser = register_parser(terminate, parent=batch_parser, help="Terminate Batch jobs")
+parser.add_argument("job_id", nargs="+")
+parser.add_argument("--reason", help="A message to attach to the job that explains the reason for canceling it")
 
 def ls(args, page_size=100):
-    table, job_ids = [], []
-    for q in args.queues or [q["jobQueueName"] for q in clients.batch.describe_job_queues()["jobQueues"]]:
-        for s in args.status:
-            job_ids.extend(j["jobId"] for j in clients.batch.list_jobs(jobQueue=q, jobStatus=s)["jobSummaryList"])
-    for i in range(0, len(job_ids), page_size):
-        table.extend(clients.batch.describe_jobs(jobs=job_ids[i:i + page_size])["jobs"])
+    queues = args.queues or [q["jobQueueName"] for q in clients.batch.describe_job_queues()["jobQueues"]]
+
+    def list_jobs_worker(list_jobs_worker_args):
+        queue, status = list_jobs_worker_args
+        return [j["jobId"] for j in clients.batch.list_jobs(jobQueue=queue, jobStatus=status)["jobSummaryList"]]
+
+    with concurrent.futures.ThreadPoolExecutor() as executor:
+        job_ids = sum(executor.map(list_jobs_worker, itertools.product(queues, args.status)), [])
+
+        def describe_jobs_worker(start_index):
+            return clients.batch.describe_jobs(jobs=job_ids[start_index:start_index + page_size])["jobs"]
+
+        table = sum(executor.map(describe_jobs_worker, range(0, len(job_ids), page_size)), [])
     page_output(tabulate(table, args, cell_transforms={"createdAt": Timestamp}))
 
 job_status_colors = dict(SUBMITTED=YELLOW(), PENDING=YELLOW(), RUNNABLE=BOLD() + YELLOW(),
