@@ -171,7 +171,10 @@ def ensure_s3_bucket(name=None, policy=None, lifecycle=None):
     if name is None:
         name = "aegea-assets-{}".format(ARN.get_account_id())
     bucket = resources.s3.Bucket(name)
-    if not bucket.creation_date:
+    try:
+        clients.s3.head_bucket(Bucket=bucket.name)
+    except ClientError as e:
+        logger.debug(e)
         if ARN.get_region() == "us-east-1":
             bucket.create()
         else:
@@ -578,7 +581,7 @@ def instance_type_completer(max_cache_age_days=30, **kwargs):
     return [p["instanceType"] for p in get_products("AmazonEC2")]
 
 instance_storage_shellcode = """
-aegea_bd=(/dev/disk/by-id/nvme-Amazon_EC2_NVMe_Instance_Storage_AWS?????????????????)
+aegea_bd=( $(shopt -s nullglob; readlink -f /dev/disk/by-id/nvme-Amazon_EC2_NVMe_Instance_Storage_AWS{{?????????????????,?????????????????-ns-?}} | sort | uniq) )
 if [ ! -e /dev/md0 ]; then mdadm --create /dev/md0 --force --auto=yes --level=0 --chunk=256 --raid-devices=${{#aegea_bd[@]}} ${{aegea_bd[@]}}; {mkfs} /dev/md0; fi
 mount -L aegveph {mountpoint}
 """  # noqa
