@@ -98,7 +98,7 @@ def get_command_and_env(args):
         shellcode += commands
 
     if args.execute:
-        bucket = ensure_s3_bucket("aegea-batch-jobs-{}".format(ARN.get_account_id()))
+        bucket = ensure_s3_bucket(args.staging_s3_bucket or "aegea-batch-jobs-" + ARN.get_account_id())
 
         key_name = hashlib.sha256(args.execute.read()).hexdigest()
         args.execute.seek(0)
@@ -112,12 +112,12 @@ def get_command_and_env(args):
         shellcode += ['BATCH_SCRIPT=$(mktemp --tmpdir "{tmpdir_fmt}")'.format(tmpdir_fmt=tmpdir_fmt),
                       "apt-get update -qq",
                       "apt-get install -qqy --no-install-suggests --no-install-recommends curl ca-certificates gnupg",
-                      "curl '{payload_url}' > $BATCH_SCRIPT".format(payload_url=payload_url),
+                      "curl -L '{payload_url}' > $BATCH_SCRIPT".format(payload_url=payload_url),
                       "chmod +x $BATCH_SCRIPT",
                       "$BATCH_SCRIPT"]
     elif args.cwl:
         ensure_dynamodb_table("aegea-batch-jobs", hash_key_name="job_id")
-        bucket = ensure_s3_bucket("aegea-batch-jobs-{}".format(ARN.get_account_id()))
+        bucket = ensure_s3_bucket(args.staging_s3_bucket or "aegea-batch-jobs-" + ARN.get_account_id())
         args.environment.append(dict(name="AEGEA_BATCH_S3_BASE_URL", value="s3://" + bucket.name))
 
         from cwltool.main import main as cwltool_main
