@@ -89,7 +89,7 @@ class TestAegea(unittest.TestCase):
             elif subcommand == "rm":
                 args += [resolve_ami()]
             elif subcommand in ("secrets", "rds", "elb", "flow-logs", "deploy", "zones", "ebs", "buckets", "efs",
-                                "ecr", "lambda", "configure"):
+                                "ecr", "lambda", "configure", "sfn"):
                 args += ["ls"]
             elif subcommand == "pricing":
                 args += ["AmazonS3", "--json"]
@@ -283,6 +283,7 @@ class TestAegea(unittest.TestCase):
         self.call("aegea secrets delete {s} --iam-role aegea.launch".format(s=secret_name), shell=True,
                   expect=unauthorized_ok)
 
+    @unittest.skipIf("CI" in os.environ, "requires elevated AWS privileges")
     def test_ensure_job_definition(self):
         from aegea.batch import submit_parser
         jd1 = ensure_job_definition(submit_parser.parse_args(["--command", ""]))
